@@ -15,7 +15,7 @@ with 'WWW::FBX::Role::Auth';
  
 use namespace::autoclean;
 
-our $VERSION = "0.18";
+our $VERSION = "0.19";
 
 has base_url    => ( isa => 'Str', is => 'ro', default => 'http://mafreebox.free.fr' );
 has lwp_args    => ( isa => 'HashRef', is => 'ro', default => sub { {} } );
@@ -233,20 +233,18 @@ Api methods will I<die> if the APIResponse is an error. It is up to the caller t
 
 The list of currently available services implemented in this module is given in L<WWW::FBX::Role::API::APIv3>.
 
-A script called fbx_test.pl is provided in script to show how to send commands and handle exceptions. 
+A script called fbx_test.pl is provided in the script directory.
 
-It can also be used standalone to get tokens and send a command.
+You should first call it without argument to store a token in app_token on the disk. Once physically authenticated on the freebox itself, the token file will be reused for subsequent call. You can then grant all permissions on the freebox web interface if you will.
 
-On first call, you will be requested to physically authenticate on the freebox itself. Once done, the token is stored in the current directory in a file called app_token. You can then grant all permissions on the freebox web interface to allow all commands.
+Witout parameter, a simple connection check is done, app permissions are shows and status of the internet connection is displayed.
 
-When suffix parameter is required, pass it as a normal parameter.
-
-When more parameters are required, it is possible to send a json structure, see EXAMPLES. You need to escape the accolades though.
+Commands requiring a suffix can be send by adding a simple parameters on the command line. When more parameters are required, it is possible to send a json structure, see EXAMPLES. You need to escape the accolades in that case.
 
 =head1 EXAMPLES
 
  fbx-test.pl --help
- fbx-test.pl connection
+ fbx-test.pl --debug connection
  fbx-test.pl system
  fbx-test.pl call_log
  fbx-test.pl call_log 2053
